@@ -3,15 +3,14 @@
 #' @inheritParams BatchtoolsFuture
 #'
 #' @param cluster.functions A
-#' \link[batchtools:ClusterFunctions]{ClusterFunctions} object.
+#' [ClusterFunctions][batchtools::ClusterFunctions] object.
 #'
 #' @param resources A named list passed to the batchtools template
-#' (available as variable \code{resources}).
+#' (available as variable `resources`).
 #'
-#' @param \ldots Additional arguments passed to
-#' \code{\link{BatchtoolsFuture}()}.
+#' @param \ldots Additional arguments passed to [BatchtoolsFuture()].
 #'
-#' @return An object of class \code{BatchtoolsFuture}.
+#' @return An object of class `BatchtoolsFuture`.
 #'
 #' @export
 #' @importFrom utils file_test
@@ -20,7 +19,7 @@ batchtools_custom <- function(expr, envir = parent.frame(), substitute = TRUE,
                               cluster.functions,
                               resources = list(), workers = NULL, ...) {
   if (substitute) expr <- substitute(expr)
-  stopifnot(inherits(cluster.functions, "ClusterFunctions"))
+  stop_if_not(inherits(cluster.functions, "ClusterFunctions"))
 
   future <- BatchtoolsFuture(expr = expr, envir = envir, substitute = FALSE,
                             globals = globals,
