@@ -4,8 +4,12 @@ message("*** Futures - lazy ...")
 
 strategies <- c("batchtools_local")
 
+## CRAN processing times:
+## On Windows 32-bit, don't run these tests
+if (!fullTest && isWin32) strategies <- character(0L)
+
 for (strategy in strategies) {
-  mprintf("- plan('%s') ...", strategy)
+  mprintf("- plan('%s') ...\n", strategy)
   plan(strategy)
 
   a <- 42
@@ -19,7 +23,7 @@ for (strategy in strategies) {
   a <- 21
   stopifnot(v == 84)
 
-  mprintf("- plan('%s') ... DONE", strategy)
+  mprintf("- plan('%s') ... DONE\n", strategy)
 } ## for (strategy ...)
 
 message("*** Futures - lazy ... DONE")
